﻿// <copyright file="FocusExtension.cs" company="CGI Federal, Inc.">
//  Copyright CGI Federal, Inc., all rights reserved
// </copyright>
// <author>Eric Murchie-Beyma</author>

namespace BindingIssue
{
    using System;
    using System.Windows;
    using System.Diagnostics;

    /// <summary>
    /// Attached Property allowing Focus to be set for any Control
    /// </summary>
    public static class FocusExtension
    {

        public static readonly DependencyProperty IsFocusedProperty =
            DependencyProperty.RegisterAttached(
                "IsFocused",
                typeof(bool?),
                typeof(FocusExtension),
                new PropertyMetadata(null, IsFocusedChanged)); 

        public static bool? GetIsFocused(DependencyObject element) 
        { 
            if (element == null) 
            { 
                throw new ArgumentNullException("element"); 
            }
 
            return (bool?)element.GetValue(IsFocusedProperty); 
        } 

        public static void SetIsFocused(DependencyObject element, bool? value) 
        { 
            if (element == null) 
            { 
                throw new ArgumentNullException("element"); 
            }
 
            element.SetValue(IsFocusedProperty, value); 
        } 
                
        private static void IsFocusedChanged(DependencyObject d, DependencyPropertyChangedEventArgs e) 
        { 
            var fe = (FrameworkElement)d;
            if (e.OldValue == null)
            {
                fe.GotFocus += FrameworkElement_GotFocus;
                fe.LostFocus += FrameworkElement_LostFocus;
            }
            Debug.WriteLine(fe + " - " + e.NewValue);
            if (e.NewValue != null)
            {
                if ((bool)e.NewValue)
                {
                    fe.Focus();
                }
            }
        } 

        private static void FrameworkElement_GotFocus(object sender, RoutedEventArgs e) 
        { 
          //  ((FrameworkElement)sender).SetValue(IsFocusedProperty, true);
            Debug.WriteLine("Got - "  + sender);
        }

        private static void FrameworkElement_LostFocus(object sender, RoutedEventArgs e) 
        { 
          //  ((FrameworkElement)sender).SetValue(IsFocusedProperty, false);
            Debug.WriteLine("Lost - " + sender);
        } 
    }

}
